==> sqlitedbms-0.2.0.tar.gz: sqlitedbms-0.2.0/src/include/define.h <==
#define	TRUE				1
#define	FALSE				0

#define	MAX(x,y)			(x>y?x:y)
#define	MIN(x,y)			(x<y?x:y)

#define DEBUG				printf("DEBUG: %s: %d\n", __FILE__, __LINE__);

#define	THREAD_INIT			1
#define	THREAD_WAIT			2
#define	THREAD_WORK			3

/* DEFAULT_ENV */
#define ENV_DEF_FILEPATH		"conf/sqlitedbms.conf"
#define ENV_DEF_PORT			6543
#define ENV_DEF_MAX_SESSION		1024
#define ENV_DEF_POLL_TIMEOUT		10
#define ENV_DEF_USER			"nobody"
#define	ENV_DEF_BUF_HEADER		1024*4
#define	ENV_DEF_BUF_RECV		1024*256
#define	ENV_DEF_BUF_SEND		1024*1024

#define	ENV_DEF_DB_PATH			"data"
#define	ENV_DEF_DB_REP_PATH		"data_rep"

#define ENV_DEF_HTTP_USE		TRUE
#define ENV_DEF_HTTP_ROOT		"htdocs"
#define ENV_DEF_HTTP_TIMEOUT		60

#define	ENV_DEF_LOG_PATH		"logs"

#define	ENV_MAX				20

/* LIMIT */
#define	LIMIT_MAX_DBNAME		1024
#define	LIMIT_MAX_DBFILENAME		1024*4
#define LIMIT_BUF_INCREMENT		1024*256

/* CATALOG */
#define	CATALOG_INIT_USER		"admin"
#define	CATALOG_INIT_PASS		"password"
#define	CATALOG_INIT_USER_SQL		"CREATE TABLE USER (id text, pass text, super int, db text, unique(id, db)); INSERT INTO USER VALUES('%q', '%q', 1, '*')"
#define	CATALOG_GET_USER_SQL		"SELECT super FROM USER WHERE id='%q' and pass='%q' and (db='*' or db='%q')"

/* ADMIN SQL */
#define	ADMIN_SQL_CREATE_USER		"INSERT INTO USER (id, pass, super, db) values('%q', '%q', '%d', '%q')"
#define	ADMIN_SQL_DROP_USER1		"DELETE FROM USER WHERE id='%q'"
#define	ADMIN_SQL_DROP_USER2		"DELETE FROM USER WHERE id='%q' AND db='%q'"

#define ADMIN_USER_MANAGE_CREATE	1
#define ADMIN_USER_MANAGE_DROP1		2
#define ADMIN_USER_MANAGE_DROP2		3

/* XML DEFINE */
#define XML_ERROR_OPEN			"<error><message>"
#define XML_ERROR_CLOSE			"</message></error>"
#define XML_INFO_OPEN			"<info><message>"
#define XML_INFO_CLOSE			"</message></info>"

#define XML_RESPONSE_OPEN		"<response>\n<changes>%d</changes><rowid>%lld</rowid><rows>%d</rows>\n"
#define XML_RESPONSE_COLUMNS_OPEN	"<columns>"
#define XML_RESPONSE_COLUMN_OPEN	"<columnname>"
#define XML_RESPONSE_COLUMN_CLOSE	"</columnname>"
#define XML_RESPONSE_COLUMNS_CLOSE	"</columns>\n"
#define XML_RESPONSE_ROW_OPEN		"<row>"
#define XML_RESPONSE_DATA_OPEN		"<data>"
#define XML_RESPONSE_DATA_CLOSE		"</data>"
#define XML_RESPONSE_ROW_CLOSE		"</row>\n"
#define XML_RESPONSE_CLOSE		"</response>"

#define XML_MONITOR			"<session><process>%d</process><db>%s</db><user>%s</user><status>%s</status><worksql>%s</worksql><since><init>%d</init><idle>%d</idle></since></session>\n"

/* HTTP REQUEST */
#define	REQUEST_METHOD_POST		1
#define	REQUEST_METHOD_GET		2
#define	REQUEST_METHOD_HEAD		4

/* RESPONSE */
#define	RESPONSE_ERR_BAD_REQUEST	0
#define	RESPONSE_ERR_UNAUTHORIZED	1
#define	RESPONSE_ERR_INTERNAL		2
#define	RESPONSE_ERR_DB_CREATE		3
#define	RESPONSE_ERR_DB_FOUND		4
#define	RESPONSE_ERR_DB_DROP		5
#define	RESPONSE_ERR_USER_CREATE	6
#define	RESPONSE_ERR_USER_FOUND		7
#define	RESPONSE_ERR_USER_DROP		8
#define	RESPONSE_ERR_NOT_FOUND		9

#define	RESPONSE_INFO_DB_CREATE		0
#define	RESPONSE_INFO_DB_DROP		1
#define	RESPONSE_INFO_USER_CREATE	2
#define	RESPONSE_INFO_USER_DROP		3
#define	RESPONSE_INFO_USER_ALTER	4
#define	RESPONSE_INFO_LOGIN_SUCCESS	5

#define	HTTP_DEFAULT_INDEX		"index.htm"

/* SQLITE ERROR */
#define	SQLITE_ERROR_SEND		1001
#define	SQLITE_ERROR_ADMIN		1002
#define	SQLITE_ERROR_EXTEND		1003

==> sqlitedbms-0.2.2.tar.gz: sqlitedbms-0.2.2/src/include/define.h <==
#define	TRUE				1
#define	FALSE				0

#define	MAX(x,y)			(x>y?x:y)
#define	MIN(x,y)			(x<y?x:y)

#define DEBUG				printf("----- DEBUG: %s: %d\n", __FILE__, __LINE__);

#define	THREAD_INIT			1
#define	THREAD_WAIT			2
#define	THREAD_WORK			3

/* DEFAULT_ENV */
#define ENV_DEF_FILEPATH		"conf/sqlitedbms.conf"
#define ENV_DEF_PORT			6543
#define ENV_DEF_MAX_SESSION		1024
#define ENV_DEF_POLL_TIMEOUT		10
#define	ENV_DEF_ACCESS_CONTROL		FALSE
#define ENV_DEF_USER			"nobody"
#define	ENV_DEF_BUF_HEADER		1024*4
#define	ENV_DEF_BUF_RECV		1024*256
#define	ENV_DEF_BUF_SEND		1024*1024

#define	ENV_DEF_DB_PATH			"data"
#define	ENV_DEF_DB_REP_PATH		"data_rep"

#define ENV_DEF_HTTP_USE		TRUE
#define ENV_DEF_HTTP_ROOT		"htdocs"
#define ENV_DEF_HTTP_TIMEOUT		60

#define	ENV_DEF_LOG_PATH		"logs"

#define	ENV_MAX				20

/* LIMIT */
#define	LIMIT_MAX_DBNAME		1024
#define	LIMIT_MAX_DBFILENAME		1024*4
#define LIMIT_BUF_INCREMENT		1024*256

/* CATALOG */
#define	CATALOG_INIT_USER		"admin"
#define	CATALOG_INIT_PASS		"password"
#define	CATALOG_INIT_USER_SQL		"CREATE TABLE USER (id text PRIMARY KEY, pass text, super int);CREATE TABLE GRANT_DB (id text, db text, grant text, PRIMARY KEY(id, db));CREATE TABLE GRANT_OBJECT (id text, db text, object text, grant text, PRIMARY KEY(id, db, object));INSERT INTO USER VALUES('%q', '%q', 1);"
#define	CATALOG_GET_USER_SQL		"SELECT super FROM USER WHERE id='%q' and pass='%q'"

/* ADMIN SQL */
#define	ADMIN_SQL_CREATE_USER		"INSERT INTO USER (id, pass, super) values('%q', '%q', '%d')"
#define	ADMIN_SQL_DROP_USER1		"DELETE FROM USER WHERE id='%q'"
#define	ADMIN_SQL_DROP_USER2		"DELETE FROM USER WHERE id='%q' AND db='%q'"

#define ADMIN_USER_MANAGE_CREATE	1
#define ADMIN_USER_MANAGE_DROP1		2
#define ADMIN_USER_MANAGE_DROP2		3

/* XML DEFINE */
#define XML_ERROR_OPEN			"<error><message>"
#define XML_ERROR_CLOSE			"</message></error>"
#define XML_INFO_OPEN			"<info><message>"
#define XML_INFO_CLOSE			"</message></info>"

#define XML_RESPONSE_OPEN		"<response>\n<changes>%d</changes><rowid>%lld</rowid><rows>%d</rows><time>%ld.%06ld</time>\n"
#define XML_RESPONSE_COLUMNS_OPEN	"<columns>"
#define XML_RESPONSE_COLUMN_OPEN	"<columnname>"
#define XML_RESPONSE_COLUMN_CLOSE	"</columnname>"
#define XML_RESPONSE_COLUMNS_CLOSE	"</columns>\n"
#define XML_RESPONSE_ROW_OPEN		"<row>"
#define XML_RESPONSE_DATA_OPEN		"<data>"
#define XML_RESPONSE_DATA_CLOSE		"</data>"
#define XML_RESPONSE_ROW_CLOSE		"</row>\n"
#define XML_RESPONSE_CLOSE		"</response>"

#define XML_MONITOR			"<row><data>%ld</data><data>%s</data><data>%s</data><data>%s</data><data>%s</data><data>%ld</data><data>%ld</data></row>\n"

/* HTTP REQUEST */
#define	REQUEST_METHOD_POST		1
#define	REQUEST_METHOD_GET		2
#define	REQUEST_METHOD_HEAD		4

/* RESPONSE */
#define	RESPONSE_ERR_BAD_REQUEST	0
#define	RESPONSE_ERR_UNAUTHORIZED	1
#define	RESPONSE_ERR_INTERNAL		2
#define	RESPONSE_ERR_DB_CREATE		3
#define	RESPONSE_ERR_DB_FOUND		4
#define	RESPONSE_ERR_DB_DROP		5
#define	RESPONSE_ERR_USER_CREATE	6
#define	RESPONSE_ERR_USER_FOUND		7
#define	RESPONSE_ERR_USER_DROP		8
#define	RESPONSE_ERR_NOT_FOUND		9
#define	RESPONSE_ERR_GRANT		10
#define	RESPONSE_ERR_REVOKE		11

#define	RESPONSE_INFO_DB_CREATE		0
#define	RESPONSE_INFO_DB_DROP		1
#define	RESPONSE_INFO_USER_CREATE	2
#define	RESPONSE_INFO_USER_DROP		3
#define	RESPONSE_INFO_USER_ALTER	4
#define	RESPONSE_INFO_LOGIN_SUCCESS	5
#define	RESPONSE_INFO_GRANT		6
#define	RESPONSE_INFO_REVOKE		7

#define	HTTP_DEFAULT_INDEX		"index.htm"

/* SQLITE ERROR */
#define	SQLITE_ERROR_SEND		1001
#define	SQLITE_ERROR_ADMIN		1002
#define	SQLITE_ERROR_EXTEND		1003

#define SQLITE_AUTH_GRANT		1
#define SQLITE_AUTH_REVOKE		2
#define SQLITE_AUTH_GRANT_CREATE	3
#define SQLITE_AUTH_REVOKE_CREATE	4

/* SQLITE AUTH TYPE */
#define	SQLITE_AUTH_TYPE_NONE		0
#define	SQLITE_AUTH_TYPE_BASE64		1

/* SQLITE AUTH EXTEND */
#define	SQLITE_SHOW			41
#define	SQLITE_DESC			42

#define	SQLITE_CREATE_DATABASE		51
#define	SQLITE_DROP_DATABASE		52
#define	SQLITE_ALTER_DATABASE		53

#define	SQLITE_CREATE_USER		61
#define	SQLITE_DROP_USER		62
#define	SQLITE_ALTER_USER		63
